@@ -24,3 +24,16 @@ class CheckBox(QWidget):
 
     def __sendCheckedSignal(self, flag):
         self.checkedSignal.emit(self.__r_idx, flag)
+
+    def isChecked(self):
+        f = self.layout().itemAt(0).widget().isChecked()
+        return Qt.Checked if f else Qt.Unchecked
+
+    def setChecked(self, f):
+        if isinstance(f, Qt.CheckState):
+            self.getCheckBox().setCheckState(f)
+        elif isinstance(f, bool):
+            self.getCheckBox().setChecked(f)
+
+    def getCheckBox(self):
+        return self.layout().itemAt(0).widget()
\ No newline at end of file
